@@ -3,24 +3,23 @@
 #ifndef DATABASEFACTORY_H
 #define DATABASEFACTORY_H
 
-#include <QObject>
-
 #include "database/databasedriver.h"
+#include "database/databaseworker.h"
 
+#include <QObject>
+#include <QPointer>
 #include <QSqlDatabase>
 
-class DatabaseFactory : public QObject {
-  Q_OBJECT
+class RSSGUARD_DLLSPEC DatabaseFactory : public QObject {
+    Q_OBJECT
 
   public:
     explicit DatabaseFactory(QObject* parent = nullptr);
 
-    // Removes connection.
-    void removeConnection(const QString& connection_name = {});
-
     // Returns identification of currently active database driver.
     DatabaseDriver::DriverType activeDatabaseDriver() const;
 
+    DatabaseWorker* worker() const;
     DatabaseDriver* driver() const;
     DatabaseDriver* driverForType(DatabaseDriver::DriverType d) const;
 
@@ -31,6 +30,7 @@ class DatabaseFactory : public QObject {
 
     QList<DatabaseDriver*> m_allDbDrivers;
     DatabaseDriver* m_dbDriver;
+    QPointer<DatabaseWorker> m_dbWorker;
 };
 
 #endif // DATABASEFACTORY_H
